@@ -46,6 +46,8 @@ void KDirListerTest::initTestCase()
     // To avoid a runtime dependency on klauncher
     qputenv("KDE_FORK_SLAVES", "yes");
 
+    KIO::setDefaultJobUiDelegateExtension(0); // no "skip" dialogs
+
     m_exitCount = 1;
 
     s_referenceTimeStamp = QDateTime::currentDateTime().addSecs(-120);   // 2 minutes ago
@@ -67,7 +69,7 @@ void KDirListerTest::initTestCase()
     createTestDirectory(path + "subdir");
     createTestDirectory(path + "subdir/subsubdir");
 
-    qRegisterMetaType<QList<QPair<KFileItem,KFileItem> > >();
+    qRegisterMetaType<QList<QPair<KFileItem, KFileItem> > >();
 }
 
 void KDirListerTest::cleanup()
@@ -264,8 +266,12 @@ void KDirListerTest::testNewItemsInSymlink() // #213799
     QVERIFY(tempFile.open());
     const QString symPath = tempFile.fileName() + "_link";
     tempFile.close();
-    bool symlinkOk = KIOPrivate::createSymlink(path, symPath);
-    QVERIFY(symlinkOk);
+    const bool symlinkOk = KIOPrivate::createSymlink(path, symPath);
+    if (!symlinkOk) {
+        const QString error = QString::fromLatin1("Failed to create symlink '%1' pointing to '%2': %3")
+            .arg(symPath, path, QString::fromLocal8Bit(strerror(errno)));
+        QVERIFY2(symlinkOk, qPrintable(error));
+    }
     MyDirLister dirLister2;
     m_items2.clear();
     connect(&dirLister2, SIGNAL(newItems(KFileItemList)), this, SLOT(slotNewItems2(KFileItemList)));
@@ -324,6 +330,8 @@ void KDirListerTest::testNewItemsInSymlink() // #213799
 
     // TODO: test file update.
     disconnect(&m_dirLister, 0, this, 0);
+
+    QFile::remove(symPath);
 }
 
 // This test assumes testOpenUrl was run before. So m_dirLister is holding the items already.
@@ -970,10 +978,9 @@ void KDirListerTest::testRenameCurrentDir() // #294445
     QDir().rmdir(newPath);
 }
 
-
-void KDirListerTest::slotOpenUrlOnRename(const QUrl & newUrl)
+void KDirListerTest::slotOpenUrlOnRename(const QUrl &newUrl)
 {
-  QVERIFY(m_dirLister.openUrl(newUrl));
+    QVERIFY(m_dirLister.openUrl(newUrl));
 }
 
 //This tests for a crash if you connect redirects to openUrl, due
@@ -1050,6 +1057,42 @@ void KDirListerTest::testRedirection()
     disconnect(&m_dirLister, 0, this, 0);
 }
 
+void KDirListerTest::testListEmptyDirFromCache() // #278431
+{
+    m_items.clear();
+
+    QTemporaryDir newDir;
+    const QUrl url = QUrl::fromLocalFile(newDir.path());
+
+    // List and watch an empty dir
+    connect(&m_dirLister, SIGNAL(newItems(KFileItemList)), this, SLOT(slotNewItems(KFileItemList)));
+    m_dirLister.openUrl(url);
+    QSignalSpy spyCompleted(&m_dirLister, SIGNAL(completed()));
+    QVERIFY(spyCompleted.wait(1000));
+    QVERIFY(m_dirLister.isFinished());
+    QVERIFY(m_items.isEmpty());
+
+    // List it with two more dirlisters (one will create a cached items job, the second should also benefit from it)
+    MyDirLister secondDirLister;
+    connect(&secondDirLister, SIGNAL(newItems(KFileItemList)), this, SLOT(slotNewItems(KFileItemList)));
+    secondDirLister.openUrl(url);
+    MyDirLister thirdDirLister;
+    connect(&thirdDirLister, SIGNAL(newItems(KFileItemList)), this, SLOT(slotNewItems(KFileItemList)));
+    thirdDirLister.openUrl(url);
+
+    // The point of this test is that (with DEBUG_CACHE enabled) it used to assert here
+    // with "HUH? Lister KDirLister(0x7ffd1f044260) is supposed to be listing, but has no job!"
+    // due to the if (!itemU->lstItems.isEmpty()) check which is now removed.
+
+    QVERIFY(!secondDirLister.isFinished()); // we didn't go to the event loop yet
+    QSignalSpy spySecondCompleted(&secondDirLister, SIGNAL(completed()));
+    QVERIFY(spySecondCompleted.wait(1000));
+    if (!thirdDirLister.isFinished()) {
+        QSignalSpy spyThirdCompleted(&thirdDirLister, SIGNAL(completed()));
+        QVERIFY(spyThirdCompleted.wait(1000));
+    }
+}
+
 void KDirListerTest::testWatchingAfterCopyJob() // #331582
 {
     m_items.clear();
@@ -1218,6 +1261,35 @@ void KDirListerTest::slotRefreshItems2(const QList<QPair<KFileItem, KFileItem> >
     m_refreshedItems2 += lst;
 }
 
+void KDirListerTest::testCopyAfterListingAndMove() // #353195
+{
+    const QString dirA = m_tempDir.path() + "/a";
+    QVERIFY(QDir().mkdir(dirA));
+    const QString dirB = m_tempDir.path() + "/b";
+    QVERIFY(QDir().mkdir(dirB));
+
+    // ensure m_dirLister holds the items.
+    m_dirLister.openUrl(QUrl::fromLocalFile(path()), KDirLister::NoFlags);
+    QSignalSpy spyCompleted(&m_dirLister, SIGNAL(completed()));
+    QVERIFY(spyCompleted.wait());
+
+    // Move b into a
+    KIO::Job *moveJob = KIO::move(QUrl::fromLocalFile(dirB), QUrl::fromLocalFile(dirA));
+    moveJob->setUiDelegate(0);
+    QVERIFY(moveJob->exec());
+    QVERIFY(QFileInfo(m_tempDir.path() + "/a/b").isDir());
+
+    // Give some time to processPendingUpdates
+    QTest::qWait(1000);
+
+    // Copy folder a elsewhere
+    const QString dest = m_tempDir.path() + "/subdir";
+    KIO::Job *copyJob = KIO::copy(QUrl::fromLocalFile(dirA), QUrl::fromLocalFile(dest));
+    copyJob->setUiDelegate(0);
+    QVERIFY(copyJob->exec());
+    QVERIFY(QFileInfo(m_tempDir.path() + "/subdir/a/b").isDir());
+}
+
 void KDirListerTest::testDeleteCurrentDir()
 {
     // ensure m_dirLister holds the items.
@@ -1254,8 +1326,9 @@ bool KDirListerTest::waitForRefreshedItems()
     int numTries = 0;
     // Give time for KDirWatch to notify us
     while (m_refreshedItems.isEmpty()) {
-        if (++numTries == 20)
+        if (++numTries == 20) {
             return false;
+        }
         QTest::qWait(100);
     }
     return true;
@@ -1298,8 +1371,7 @@ void KDirListerTest::waitUntilAfter(const QDateTime &ctime)
     QDateTime now;
     Q_FOREVER {
         now = QDateTime::currentDateTime();
-        if (now.toTime_t() == ctime.toTime_t())   // truncate milliseconds
-        {
+        if (now.toTime_t() == ctime.toTime_t()) { // truncate milliseconds
             totalWait += 50;
             QTest::qWait(50);
         } else {
