@@ -25,6 +25,11 @@
 #include <qtemporarydir.h>
 #include <qtemporaryfile.h>
 #include <kuser.h>
+#include <kdesktopfile.h>
+#include <kconfiggroup.h>
+#include "kiotesthelper.h"
+
+#include <QMimeDatabase>
 
 QTEST_MAIN(KFileItemTest)
 
@@ -38,7 +43,7 @@ void KFileItemTest::testPermissionsString()
     QTemporaryDir tempDir;
     KFileItem dirItem(QUrl::fromLocalFile(tempDir.path() + '/'));
     QCOMPARE((uint)dirItem.permissions(), (uint)0700);
-    QCOMPARE(dirItem.permissionsString(), QString("drwx------"));
+    QCOMPARE(dirItem.permissionsString(), QStringLiteral("drwx------"));
     QVERIFY(dirItem.isReadable());
 
     // File
@@ -47,7 +52,7 @@ void KFileItemTest::testPermissionsString()
     file.setPermissions(QFile::ReadOwner | QFile::WriteOwner | QFile::ReadOther); // 0604
     KFileItem fileItem(QUrl::fromLocalFile(file.fileName()), QString(), KFileItem::Unknown);
     QCOMPARE((uint)fileItem.permissions(), (uint)0604);
-    QCOMPARE(fileItem.permissionsString(), QString("-rw----r--"));
+    QCOMPARE(fileItem.permissionsString(), QStringLiteral("-rw----r--"));
     QVERIFY(fileItem.isReadable());
 
     // Symlink to file
@@ -58,7 +63,7 @@ void KFileItemTest::testPermissionsString()
     QCOMPARE((uint)symlinkItem.permissions(), (uint)0604);
     // This is a bit different from "ls -l": we get the 'l' but we see the permissions of the target.
     // This is actually useful though; the user sees it's a link, and can check if he can read the [target] file.
-    QCOMPARE(symlinkItem.permissionsString(), QString("lrw----r--"));
+    QCOMPARE(symlinkItem.permissionsString(), QStringLiteral("lrw----r--"));
     QVERIFY(symlinkItem.isReadable());
 
     // Symlink to directory (#162544)
@@ -66,14 +71,14 @@ void KFileItemTest::testPermissionsString()
     QVERIFY(QFile(tempDir.path() + '/').link(symlink));
     KFileItem symlinkToDirItem(symlinkUrl, QString(), KFileItem::Unknown);
     QCOMPARE((uint)symlinkToDirItem.permissions(), (uint)0700);
-    QCOMPARE(symlinkToDirItem.permissionsString(), QString("lrwx------"));
+    QCOMPARE(symlinkToDirItem.permissionsString(), QStringLiteral("lrwx------"));
 }
 
 void KFileItemTest::testNull()
 {
     KFileItem null;
     QVERIFY(null.isNull());
-    KFileItem fileItem(QUrl::fromLocalFile("/"), QString(), KFileItem::Unknown);
+    KFileItem fileItem(QUrl::fromLocalFile(QStringLiteral("/")), QString(), KFileItem::Unknown);
     QVERIFY(!fileItem.isNull());
     null = fileItem; // ok, now 'null' isn't so null anymore
     QVERIFY(!null.isNull());
@@ -83,7 +88,7 @@ void KFileItemTest::testNull()
 
 void KFileItemTest::testDoesNotExist()
 {
-    KFileItem fileItem(QUrl::fromLocalFile("/doesnotexist"), QString(), KFileItem::Unknown);
+    KFileItem fileItem(QUrl::fromLocalFile(QStringLiteral("/doesnotexist")), QString(), KFileItem::Unknown);
     QVERIFY(!fileItem.isNull());
     QVERIFY(!fileItem.isReadable());
     QVERIFY(fileItem.user().isEmpty());
@@ -92,19 +97,19 @@ void KFileItemTest::testDoesNotExist()
 
 void KFileItemTest::testDetach()
 {
-    KFileItem fileItem(QUrl::fromLocalFile("/one"), QString(), KFileItem::Unknown);
-    QCOMPARE(fileItem.name(), QString("one"));
+    KFileItem fileItem(QUrl::fromLocalFile(QStringLiteral("/one")), QString(), KFileItem::Unknown);
+    QCOMPARE(fileItem.name(), QStringLiteral("one"));
     KFileItem fileItem2(fileItem);
     QVERIFY(fileItem == fileItem2);
     QVERIFY(fileItem.d == fileItem2.d);
-    fileItem2.setName("two");
-    QCOMPARE(fileItem2.name(), QString("two"));
-    QCOMPARE(fileItem.name(), QString("one")); // it detached
+    fileItem2.setName(QStringLiteral("two"));
+    QCOMPARE(fileItem2.name(), QStringLiteral("two"));
+    QCOMPARE(fileItem.name(), QStringLiteral("one")); // it detached
     QVERIFY(fileItem == fileItem2);
     QVERIFY(fileItem.d != fileItem2.d);
 
     fileItem = fileItem2;
-    QCOMPARE(fileItem.name(), QString("two"));
+    QCOMPARE(fileItem.name(), QStringLiteral("two"));
     QVERIFY(fileItem == fileItem2);
     QVERIFY(fileItem.d == fileItem2.d);
     QVERIFY(!(fileItem != fileItem2));
@@ -140,10 +145,10 @@ void KFileItemTest::testRootDirectory()
     const QString rootPath = QDir::rootPath();
     QUrl url = QUrl::fromLocalFile(rootPath);
     KIO::UDSEntry entry;
-    entry.insert(KIO::UDSEntry::UDS_NAME, ".");
+    entry.insert(KIO::UDSEntry::UDS_NAME, QStringLiteral("."));
     entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
     KFileItem fileItem(entry, url);
-    QCOMPARE(fileItem.text(), QString("."));
+    QCOMPARE(fileItem.text(), QStringLiteral("."));
     QVERIFY(fileItem.isLocalFile());
     QCOMPARE(fileItem.localPath(), url.path());
     QVERIFY(fileItem.linkDest().isEmpty());
@@ -159,7 +164,7 @@ void KFileItemTest::testHiddenFile()
     QFile file(tempDir.path() + "/.hiddenfile");
     QVERIFY(file.open(QIODevice::WriteOnly));
     KFileItem fileItem(QUrl::fromLocalFile(file.fileName()), QString(), KFileItem::Unknown);
-    QCOMPARE(fileItem.text(), QString(".hiddenfile"));
+    QCOMPARE(fileItem.text(), QStringLiteral(".hiddenfile"));
     QVERIFY(fileItem.isLocalFile());
     QVERIFY(fileItem.isHidden());
 }
@@ -176,8 +181,8 @@ void KFileItemTest::testMimeTypeOnDemand()
         QVERIFY(!fileItem.isMimeTypeKnown());
         QVERIFY(!fileItem.isFinalIconKnown());
         //qDebug() << fileItem.determineMimeType().name();
-        QCOMPARE(fileItem.determineMimeType().name(), QString("application/x-zerosize"));
-        QCOMPARE(fileItem.mimetype(), QString("application/x-zerosize"));
+        QCOMPARE(fileItem.determineMimeType().name(), QStringLiteral("application/x-zerosize"));
+        QCOMPARE(fileItem.mimetype(), QStringLiteral("application/x-zerosize"));
         QVERIFY(fileItem.isMimeTypeKnown());
         QVERIFY(fileItem.isFinalIconKnown());
     }
@@ -187,7 +192,7 @@ void KFileItemTest::testMimeTypeOnDemand()
         KFileItem fileItem(QUrl::fromLocalFile(file.fileName()));
         fileItem.setDelayedMimeTypes(true);
         QVERIFY(!fileItem.isMimeTypeKnown());
-        QCOMPARE(fileItem.mimetype(), QString("application/x-zerosize"));
+        QCOMPARE(fileItem.mimetype(), QStringLiteral("application/x-zerosize"));
         QVERIFY(fileItem.isMimeTypeKnown());
     }
 
@@ -215,8 +220,8 @@ void KFileItemTest::testMimeTypeOnDemand()
         QVERIFY(fileItem.currentMimeType().isValid());
         QVERIFY(fileItem.currentMimeType().isDefault());
         QVERIFY(!fileItem.isMimeTypeKnown());
-        QCOMPARE(fileItem.determineMimeType().name(), QString("application/pdf"));
-        QCOMPARE(fileItem.mimetype(), QString("application/pdf"));
+        QCOMPARE(fileItem.determineMimeType().name(), QStringLiteral("application/pdf"));
+        QCOMPARE(fileItem.mimetype(), QStringLiteral("application/pdf"));
     }
 
     {
@@ -230,14 +235,14 @@ void KFileItemTest::testMimeTypeOnDemand()
         file.close();
         KFileItem fileItem(QUrl::fromLocalFile(fileName));
         fileItem.setDelayedMimeTypes(true);
-        QCOMPARE(fileItem.currentMimeType().name(), QString("text/plain"));
+        QCOMPARE(fileItem.currentMimeType().name(), QStringLiteral("text/plain"));
         QVERIFY(fileItem.isMimeTypeKnown());
-        QCOMPARE(fileItem.determineMimeType().name(), QString("text/plain"));
-        QCOMPARE(fileItem.mimetype(), QString("text/plain"));
+        QCOMPARE(fileItem.determineMimeType().name(), QStringLiteral("text/plain"));
+        QCOMPARE(fileItem.mimetype(), QStringLiteral("text/plain"));
 
         // And if the mimetype is not on demand?
         KFileItem fileItem2(QUrl::fromLocalFile(fileName));
-        QCOMPARE(fileItem2.currentMimeType().name(), QString("text/plain")); // XDG says: application/smil; but can't sniff all files so this can't work
+        QCOMPARE(fileItem2.currentMimeType().name(), QStringLiteral("text/plain")); // XDG says: application/smil; but can't sniff all files so this can't work
         QVERIFY(fileItem2.isMimeTypeKnown());
     }
 }
@@ -259,19 +264,91 @@ void KFileItemTest::testCmp()
 void KFileItemTest::testRename()
 {
     KIO::UDSEntry entry;
-    const QString origName = QString::fromLatin1("foo");
+    const QString origName = QStringLiteral("foo");
     entry.insert(KIO::UDSEntry::UDS_NAME, origName);
     entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
-    KFileItem fileItem(entry, QUrl::fromLocalFile("/dir/foo"));
+    KFileItem fileItem(entry, QUrl::fromLocalFile(QStringLiteral("/dir/foo")));
     QCOMPARE(fileItem.name(), origName);
     QCOMPARE(fileItem.text(), origName);
-    const QString newName = QString::fromLatin1("FiNeX_rocks");
+    const QString newName = QStringLiteral("FiNeX_rocks");
     fileItem.setName(newName);
     QCOMPARE(fileItem.name(), newName);
     QCOMPARE(fileItem.text(), newName);
     QCOMPARE(fileItem.entry().stringValue(KIO::UDSEntry::UDS_NAME), newName); // #195385
 }
 
+void KFileItemTest::testRefresh()
+{
+    QTemporaryDir tempDir;
+    QFileInfo dirInfo(tempDir.path());
+    // Refresh on a dir
+    KFileItem dirItem(QUrl::fromLocalFile(tempDir.path()));
+    QVERIFY(dirItem.isDir());
+    QVERIFY(dirItem.entry().isDir());
+    QDateTime lastModified = dirInfo.lastModified();
+    // Qt 5.8 adds milliseconds (but UDSEntry has no support for that)
+    lastModified = lastModified.addMSecs(-lastModified.time().msec());
+    QCOMPARE(dirItem.time(KFileItem::ModificationTime), lastModified);
+    dirItem.refresh();
+    QVERIFY(dirItem.isDir());
+    QVERIFY(dirItem.entry().isDir());
+    QCOMPARE(dirItem.time(KFileItem::ModificationTime), lastModified);
+
+    // Refresh on a file
+    QFile file(tempDir.path() + "/afile");
+    QVERIFY(file.open(QIODevice::WriteOnly));
+    file.write("Hello world\n");
+    file.close();
+    QFileInfo fileInfo(file.fileName());
+    const KIO::filesize_t expectedSize = 12;
+    QCOMPARE(KIO::filesize_t(fileInfo.size()), expectedSize);
+    file.setPermissions(QFile::ReadOwner | QFile::WriteOwner | QFile::ReadOther); // 0604
+    KFileItem fileItem(QUrl::fromLocalFile(file.fileName()));
+    QVERIFY(fileItem.isFile());
+    QVERIFY(!fileItem.isLink());
+    QCOMPARE(fileItem.size(), expectedSize);
+    QCOMPARE(fileItem.user(), KUser().loginName());
+    // Qt 5.8 adds milliseconds (but UDSEntry has no support for that)
+    lastModified = dirInfo.lastModified();
+    lastModified = lastModified.addMSecs(-lastModified.time().msec());
+    QCOMPARE(fileItem.time(KFileItem::ModificationTime), lastModified);
+    fileItem.refresh();
+    QVERIFY(fileItem.isFile());
+    QVERIFY(!fileItem.isLink());
+    QCOMPARE(fileItem.size(), expectedSize);
+    QCOMPARE(fileItem.user(), KUser().loginName());
+    QCOMPARE(fileItem.time(KFileItem::ModificationTime), lastModified);
+
+    // Refresh on a symlink to a file
+    const QString symlink = tempDir.path() + "/asymlink";
+    QVERIFY(file.link(symlink));
+    QDateTime symlinkTime = QDateTime::currentDateTime().addSecs(-20);
+    // we currently lose milliseconds....
+    symlinkTime = symlinkTime.addMSecs(-symlinkTime.time().msec());
+    setTimeStamp(symlink, symlinkTime); // differenciate link time and source file time
+    const QUrl symlinkUrl = QUrl::fromLocalFile(symlink);
+    KFileItem symlinkItem(symlinkUrl);
+    QVERIFY(symlinkItem.isFile());
+    QVERIFY(symlinkItem.isLink());
+    QCOMPARE(symlinkItem.size(), expectedSize);
+    QCOMPARE(symlinkItem.time(KFileItem::ModificationTime), symlinkTime);
+    symlinkItem.refresh();
+    QVERIFY(symlinkItem.isFile());
+    QVERIFY(symlinkItem.isLink());
+    QCOMPARE(symlinkItem.size(), expectedSize);
+    QCOMPARE(symlinkItem.time(KFileItem::ModificationTime), symlinkTime);
+
+    // Symlink to directory (#162544)
+    QVERIFY(QFile::remove(symlink));
+    QVERIFY(QFile(tempDir.path() + '/').link(symlink));
+    KFileItem symlinkToDirItem(symlinkUrl);
+    QVERIFY(symlinkToDirItem.isDir());
+    QVERIFY(symlinkToDirItem.isLink());
+    symlinkToDirItem.refresh();
+    QVERIFY(symlinkToDirItem.isDir());
+    QVERIFY(symlinkToDirItem.isLink());
+}
+
 void KFileItemTest::testDotDirectory()
 {
     QTemporaryDir tempDir;
@@ -282,14 +359,14 @@ void KFileItemTest::testDotDirectory()
     {
         KFileItem fileItem(QUrl::fromLocalFile(tempDir.path() + '/'), QString(), KFileItem::Unknown);
         QVERIFY(fileItem.isLocalFile());
-        QCOMPARE(fileItem.mimeComment(), QString::fromLatin1("com"));
-        QCOMPARE(fileItem.iconName(), QString::fromLatin1("foo"));
+        QCOMPARE(fileItem.mimeComment(), QStringLiteral("com"));
+        QCOMPARE(fileItem.iconName(), QStringLiteral("foo"));
     }
     // Test for calling iconName first, to trigger mimetype resolution
     {
         KFileItem fileItem(QUrl::fromLocalFile(tempDir.path()), QString(), KFileItem::Unknown);
         QVERIFY(fileItem.isLocalFile());
-        QCOMPARE(fileItem.iconName(), QString::fromLatin1("foo"));
+        QCOMPARE(fileItem.iconName(), QStringLiteral("foo"));
     }
 }
 
@@ -299,7 +376,7 @@ void KFileItemTest::testDecodeFileName_data()
     QTest::addColumn<QString>("expectedText");
 
     QTest::newRow("simple") << "filename" << "filename";
-    QTest::newRow("/ at end") << QString(QString("foo") + QChar(0x2044)) << QString(QString("foo") + QChar(0x2044));
+    QTest::newRow("/ at end") << QString(QStringLiteral("foo") + QChar(0x2044)) << QString(QStringLiteral("foo") + QChar(0x2044));
     QTest::newRow("/ at begin") << QString(QChar(0x2044)) << QString(QChar(0x2044));
 }
 
@@ -316,7 +393,7 @@ void KFileItemTest::testEncodeFileName_data()
     QTest::addColumn<QString>("expectedFileName");
 
     QTest::newRow("simple") << "filename" << "filename";
-    QTest::newRow("/ at end") << "foo/" << QString(QString("foo") + QChar(0x2044));
+    QTest::newRow("/ at end") << "foo/" << QString(QStringLiteral("foo") + QChar(0x2044));
     QTest::newRow("/ at begin") << "/" << QString(QChar(0x2044));
 }
 
@@ -369,7 +446,7 @@ void KFileItemTest::testListProperties()
         switch (itemDescriptions[i].toLatin1()) {
         case 'f': {
             if (i == 1) { // 2nd file is html
-                fileName += ".html";
+                fileName += QLatin1String(".html");
             }
             QFile file(fileName);
             QVERIFY(file.open(QIODevice::WriteOnly));
@@ -384,10 +461,10 @@ void KFileItemTest::testListProperties()
             items << KFileItem(QUrl::fromLocalFile(fileName), QString(), KFileItem::Unknown);
             break;
         case '/':
-            items << KFileItem(QUrl::fromLocalFile("/"), QString(), KFileItem::Unknown);
+            items << KFileItem(QUrl::fromLocalFile(QStringLiteral("/")), QString(), KFileItem::Unknown);
             break;
         case 'h':
-            items << KFileItem(QUrl("http://www.kde.org"), QString(), KFileItem::Unknown);
+            items << KFileItem(QUrl(QStringLiteral("http://www.kde.org")), QString(), KFileItem::Unknown);
             break;
         default:
             QVERIFY(false);
@@ -408,7 +485,7 @@ void KFileItemTest::testIconNameForUrl_data()
     QTest::addColumn<QString>("expectedIcon");
 
     QTest::newRow("root") << "file:/" << "folder"; // the icon comes from KProtocolInfo
-    if (QFile::exists("/tmp")) {
+    if (QFile::exists(QStringLiteral("/tmp"))) {
         QTest::newRow("subdir") << "file:/tmp" << "inode-directory";
     }
     // TODO more tests
@@ -425,9 +502,9 @@ void KFileItemTest::testIconNameForUrl()
 void KFileItemTest::testMimetypeForRemoteFolder()
 {
     KIO::UDSEntry entry;
-    entry.insert(KIO::UDSEntry::UDS_NAME, "foo");
+    entry.insert(KIO::UDSEntry::UDS_NAME, QStringLiteral("foo"));
     entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
-    QUrl url("smb://remoteFolder/foo");
+    QUrl url(QStringLiteral("smb://remoteFolder/foo"));
     KFileItem fileItem(entry, url);
 
     QCOMPARE(fileItem.mimetype(), QStringLiteral("inode/directory"));
@@ -436,12 +513,14 @@ void KFileItemTest::testMimetypeForRemoteFolder()
 void KFileItemTest::testMimetypeForRemoteFolderWithFileType()
 {
     QString udsMimeType = QStringLiteral("application/x-smb-workgroup");
+    QVERIFY2(QMimeDatabase().mimeTypeForName(udsMimeType).isValid(),
+             qPrintable(QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation).join(':'))); // kcoreaddons installed? XDG_DATA_DIRS set?
     KIO::UDSEntry entry;
-    entry.insert(KIO::UDSEntry::UDS_NAME, "foo");
+    entry.insert(KIO::UDSEntry::UDS_NAME, QStringLiteral("foo"));
     entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
     entry.insert(KIO::UDSEntry::UDS_MIME_TYPE, udsMimeType);
 
-    QUrl url("smb://remoteFolder/foo");
+    QUrl url(QStringLiteral("smb://remoteFolder/foo"));
     KFileItem fileItem(entry, url);
 
     QCOMPARE(fileItem.mimetype(), udsMimeType);
@@ -450,9 +529,9 @@ void KFileItemTest::testMimetypeForRemoteFolderWithFileType()
 void KFileItemTest::testCurrentMimetypeForRemoteFolder()
 {
     KIO::UDSEntry entry;
-    entry.insert(KIO::UDSEntry::UDS_NAME, "foo");
+    entry.insert(KIO::UDSEntry::UDS_NAME, QStringLiteral("foo"));
     entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
-    QUrl url("smb://remoteFolder/foo");
+    QUrl url(QStringLiteral("smb://remoteFolder/foo"));
     KFileItem fileItem(entry, url);
 
     QCOMPARE(fileItem.currentMimeType().name(), QStringLiteral("inode/directory"));
@@ -462,16 +541,48 @@ void KFileItemTest::testCurrentMimetypeForRemoteFolderWithFileType()
 {
     QString udsMimeType = QStringLiteral("application/x-smb-workgroup");
     KIO::UDSEntry entry;
-    entry.insert(KIO::UDSEntry::UDS_NAME, "foo");
+    entry.insert(KIO::UDSEntry::UDS_NAME, QStringLiteral("foo"));
     entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
     entry.insert(KIO::UDSEntry::UDS_MIME_TYPE, udsMimeType);
 
-    QUrl url("smb://remoteFolder/foo");
+    QUrl url(QStringLiteral("smb://remoteFolder/foo"));
     KFileItem fileItem(entry, url);
 
     QCOMPARE(fileItem.currentMimeType().name(), udsMimeType);
 }
 
+void KFileItemTest::testIconNameForCustomFolderIcons()
+{
+    // Custom folder icons should be displayed (bug 350612)
+
+    const QString iconName = QStringLiteral("folder-music");
+
+    QTemporaryDir tempDir;
+    const QUrl url = QUrl::fromLocalFile(tempDir.path());
+    KDesktopFile cfg(tempDir.path() + QLatin1String("/.directory"));
+    cfg.desktopGroup().writeEntry("Icon", iconName);
+    cfg.sync();
+
+    KIO::UDSEntry entry;
+    entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
+    KFileItem fileItem(entry, url);
+
+    QCOMPARE(fileItem.iconName(), iconName);
+}
+
+void KFileItemTest::testIconNameForStandardPath()
+{
+    const QString iconName = QStringLiteral("folder-videos");
+    const QUrl url = QUrl::fromLocalFile(QDir::homePath() + QLatin1String("/Videos"));
+    QStandardPaths::setTestModeEnabled(true);
+
+    KIO::UDSEntry entry;
+    entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
+    KFileItem fileItem(entry, url);
+
+    QCOMPARE(fileItem.iconName(), iconName);
+}
+
 #ifndef Q_OS_WIN // user/group/other write permissions are not handled on windows
 
 void KFileItemTest::testIsReadable_data()
