@@ -39,6 +39,7 @@ static const quint16 testPort = 22342;
 
 class ServerThread : public QThread
 {
+    Q_OBJECT
 public:
     Server *volatile server;
     ServerThread()
@@ -311,21 +312,13 @@ void KTcpSocketTest::statesManyHosts()
         s->connectToHost(hosts[i % numHosts], 80);
         bool skip = false;
         KTcpSocket::State expectedState = KTcpSocket::ConnectingState;
-#if QT_VERSION > 0x040701
-        // Since Qt 4.6.3 the Qt-internal DNS cache returns a result (if cached) immediately
-        // but it was unreliable (when called from QTcpSocket) until 4.7.2
+
         if (i < numHosts) {
             expectedState = KTcpSocket::HostLookupState;
         } else {
             expectedState = KTcpSocket::ConnectingState;
         }
-#elif QT_VERSION < 0x040603
-        // Previously there was no caching
-        expectedState = KTcpSocket::HostLookupState;
-#else   // 4.6.3 to 4.7.1: unreliable results, skip test
-        skip = true;
-        qDebug() << "Skipping test on state(), because DNS caching is unreliable in this Qt version";
-#endif
+
         if (!skip) {
             QCOMPARE(stateToString(s->state()), stateToString(expectedState));
         } else { // let's make sure it's at least one of the two expected states
@@ -346,7 +339,10 @@ void KTcpSocketTest::statesManyHosts()
 
         s->waitForBytesWritten(-1);
         QCOMPARE(s->state(), KTcpSocket::ConnectedState);
-        s->waitForReadyRead(-1);
+        int tries = 0;
+        while (s->bytesAvailable() <= 100 && ++tries < 10) {
+            s->waitForReadyRead(-1);
+        }
         QVERIFY(s->bytesAvailable() > 100);
         if (i % (numHosts + 1)) {
             s->readAll();
@@ -362,8 +358,8 @@ void KTcpSocketTest::statesManyHosts()
         }
         if (i % 2) {
             s->close();    //close() is not very well defined for sockets so just check that it
+                           //does no harm
         }
-        //does no harm
     }
 
     s->deleteLater();
@@ -401,3 +397,5 @@ void Server::errors()
 
 QTEST_MAIN(KTcpSocketTest)
 
+#include "ktcpsockettest.moc"
+
