@@ -278,6 +278,14 @@ public:
      */
     virtual void setView(KFile::FileView viewKind);
 
+    /**
+     * Returns the current view mode.
+     * @returns KFile::FileView
+     * @see KFile::FileView
+     * @since 5.0
+     */
+    KFile::FileView viewMode() const;
+
     /**
      * Sets the way to sort files and directories.
      */
@@ -434,7 +442,7 @@ public:
      */
     virtual void setViewConfig(KConfigGroup &configGroup);
 
-    /*
+    /**
      * @returns the group set by setViewConfig configuration.
      */
     KConfigGroup *viewConfigGroup() const;
@@ -467,9 +475,9 @@ public:
      * When argument is true, files and directories are highlighted with single click and
      * selected (executed) with double click.
      *
-     * NOTE: this is not implemented in KDE 4 yet
+     * NOTE: this currently has no effect.
      *
-     * The default follows the signle/double click system setting.
+     * The default follows the single/double click system setting.
      */
     void setOnlyDoubleClickSelectsFiles(bool enable);
 
@@ -635,9 +643,9 @@ protected:
      */
     virtual void setDirLister(KDirLister *lister);
 
-    virtual void resizeEvent(QResizeEvent *event);
+    void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
 
-    virtual void keyPressEvent(QKeyEvent *event);
+    void keyPressEvent(QKeyEvent *event) Q_DECL_OVERRIDE;
 
     /**
      * Sets up all the actions. Called from the constructor, you usually
@@ -684,9 +692,9 @@ protected:
      */
     virtual void activatedMenu(const KFileItem &item, const QPoint &pos);
 
-    virtual void changeEvent(QEvent *event);
+    void changeEvent(QEvent *event) Q_DECL_OVERRIDE;
 
-    virtual bool eventFilter(QObject *watched, QEvent *event);
+    bool eventFilter(QObject *watched, QEvent *event) Q_DECL_OVERRIDE;
 
 public Q_SLOTS:
     /**
