@@ -229,7 +229,7 @@ void KSaveIOConfig::updateProxyScout(QWidget * parent)
 {
   // Inform the proxyscout kded module about changes if we cannot update,
   // ioslaves inform the end user...
-  QDBusInterface kded(QStringLiteral("org.kde.kded5"), QStringLiteral("/modules/proxyscout"), QStringLiteral("org.kde.KPAC.ProxyScout"));
+  QDBusInterface kded(QStringLiteral("org.kde.kcookiejar5"), QStringLiteral("/modules/proxyscout"), QStringLiteral("org.kde.KPAC.ProxyScout"));
   QDBusReply<void> reply = kded.call(QStringLiteral("reset"));
   if (!reply.isValid())
   {
