@@ -365,6 +365,7 @@ public:
 KApplicationView::KApplicationView(QWidget *parent)
     : QTreeView(parent), d(new KApplicationViewPrivate)
 {
+    setHeaderHidden(true);
 }
 
 KApplicationView::~KApplicationView()
@@ -476,6 +477,7 @@ public:
     QString m_command;
     QLabel *label;
     QString qMimeType;
+    QString qMimeTypeComment;
     QCheckBox *terminal;
     QCheckBox *remember;
     QCheckBox *nocloseonexit;
@@ -510,16 +512,19 @@ KOpenWithDialog::KOpenWithDialog(const QList<QUrl> &_urls, const QString &_text,
 {
     setObjectName(QStringLiteral("openwith"));
     setModal(true);
-    QString caption;
-    if (!_urls.isEmpty() && !_urls.first().isEmpty()) {
-        caption = KStringHandler::csqueeze(_urls.first().toDisplayString());
+    QString text = _text;
+    if (text.isEmpty() && !_urls.isEmpty()) {
+        if (_urls.count() == 1) {
+            const QString fileName = KStringHandler::csqueeze(_urls.first().fileName());
+            text = i18n("<qt>Select the program you want to use to open the file<br/>%1</qt>", fileName);
+        } else {
+            text = i18np("<qt>Select the program you want to use to open the file.</qt>",
+                         "<qt>Select the program you want to use to open the %1 files.</qt>", _urls.count());
+        }
     }
-    if (_urls.count() > 1) {
-        caption += QLatin1String("...");
-    }
-    setWindowTitle(caption);
+    setWindowTitle(i18n("Choose Application"));
     d->setMimeType(_urls);
-    d->init(_text, _value);
+    d->init(text, _value);
 }
 
 KOpenWithDialog::KOpenWithDialog(const QString &mimeType, const QString &value,
@@ -533,6 +538,8 @@ KOpenWithDialog::KOpenWithDialog(const QString &mimeType, const QString &value,
                         "If the program is not listed, enter the name or click "
                         "the browse button.</qt>", mimeType);
     d->qMimeType = mimeType;
+    QMimeDatabase db;
+    d->qMimeTypeComment = db.mimeTypeForName(mimeType).comment();
     d->init(text, value);
     if (d->remember) {
         d->remember->hide();
@@ -560,6 +567,8 @@ void KOpenWithDialogPrivate::setMimeType(const QList<QUrl> &_urls)
         qMimeType = mime.name();
         if (mime.isDefault()) {
             qMimeType.clear();
+        } else {
+            qMimeTypeComment = mime.comment();
         }
     } else {
         qMimeType.clear();
@@ -588,7 +597,7 @@ void KOpenWithDialogPrivate::init(const QString &_text, const QString &_value)
         combo->setLineEdit(lineEdit);
         combo->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);
         combo->setDuplicatesEnabled(false);
-        KConfigGroup cg(KSharedConfig::openConfig(), QLatin1String("Open-with settings"));
+        KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("Open-with settings"));
         int max = cg.readEntry("Maximum history", 15);
         combo->setMaxCount(max);
         int mode = cg.readEntry("CompletionMode", int(KCompletion::CompletionPopup));
@@ -663,10 +672,10 @@ void KOpenWithDialogPrivate::init(const QString &_text, const QString &_value)
 
     // check to see if we use konsole if not disable the nocloseonexit
     // because we don't know how to do this on other terminal applications
-    KConfigGroup confGroup(KSharedConfig::openConfig(), QLatin1String("General"));
+    KConfigGroup confGroup(KSharedConfig::openConfig(), QStringLiteral("General"));
     QString preferredTerminal = confGroup.readPathEntry("TerminalApplication", QStringLiteral("konsole"));
 
-    if (bReadOnly || preferredTerminal != QLatin1String("konsole")) {
+    if (bReadOnly || preferredTerminal != QStringLiteral("konsole")) {
         nocloseonexit->hide();
     }
 
@@ -674,7 +683,7 @@ void KOpenWithDialogPrivate::init(const QString &_text, const QString &_value)
     topLayout->addLayout(nocloseonexitLayout);
 
     if (!qMimeType.isNull()) {
-        remember = new QCheckBox(i18n("&Remember application association for this type of file"), q);
+        remember = new QCheckBox(i18n("&Remember application association for all files of type\n\"%1\" (%2)", qMimeTypeComment, qMimeType));
         //    remember->setChecked(true);
         topLayout->addWidget(remember);
     } else {
@@ -884,14 +893,14 @@ bool KOpenWithDialogPrivate::checkAccept()
     }
 
     if (terminal->isChecked()) {
-        KConfigGroup confGroup(KSharedConfig::openConfig(), QLatin1String("General"));
+        KConfigGroup confGroup(KSharedConfig::openConfig(), QStringLiteral("General"));
         preferredTerminal = confGroup.readPathEntry("TerminalApplication", QStringLiteral("konsole"));
         m_command = preferredTerminal;
         // only add --noclose when we are sure it is konsole we're using
-        if (preferredTerminal == QLatin1String("konsole") && nocloseonexit->isChecked()) {
-            m_command += QLatin1String(" --noclose");
+        if (preferredTerminal == QStringLiteral("konsole") && nocloseonexit->isChecked()) {
+            m_command += QStringLiteral(" --noclose");
         }
-        m_command += QLatin1String(" -e ");
+        m_command += QStringLiteral(" -e ");
         m_command += edit->text();
         // qDebug() << "Setting m_command to" << m_command;
     }
@@ -1017,7 +1026,7 @@ void KOpenWithDialogPrivate::saveComboboxHistory()
     if (combo) {
         combo->addToHistory(edit->text());
 
-        KConfigGroup cg(KSharedConfig::openConfig(), QLatin1String("Open-with settings"));
+        KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("Open-with settings"));
         cg.writeEntry("History", combo->historyItems());
         writeEntry(cg, "CompletionMode", combo->completionMode());
         // don't store the completion-list, as it contains all of KUrlCompletion's
