@@ -20,23 +20,21 @@
 */
 
 #include "kio/renamedialog.h"
-#include <stdio.h>
-#include <assert.h>
 
-#include <QtCore/QDate>
+#include <QApplication>
 #include <QCheckBox>
+#include <QDate>
+#include <QDebug>
+#include <QDesktopWidget>
+#include <QDir>
 #include <QLabel>
 #include <QLayout>
+#include <QLineEdit>
+#include <QMimeDatabase>
 #include <QPixmap>
+#include <QPushButton>
 #include <QScrollArea>
 #include <QScrollBar>
-#include <QApplication>
-#include <QLineEdit>
-#include <QDesktopWidget>
-#include <QPushButton>
-#include <QtCore/QDir>
-#include <qmimedatabase.h>
-#include <QDebug>
 
 #include <kiconloader.h>
 #include <kmessagebox.h>
@@ -56,6 +54,42 @@
 
 using namespace KIO;
 
+static QLabel *createLabel(QWidget *parent, const QString &text, bool containerTitle = false)
+{
+    QLabel *label = new QLabel(parent);
+
+    if (containerTitle) {
+        QFont font = label->font();
+        font.setBold(true);
+        label->setFont(font);
+    }
+
+    label->setAlignment(Qt::AlignHCenter);
+    label->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
+    label->setText(text);
+    return label;
+}
+
+static QLabel *createDateLabel(QWidget *parent, const KFileItem &item)
+{
+    const QString text = i18n("Date: %1", item.timeString(KFileItem::ModificationTime));
+    return createLabel(parent, text);
+}
+
+static QLabel *createSizeLabel(QWidget *parent, const KFileItem &item)
+{
+    const QString text = i18n("Size: %1", KIO::convertSize(item.size()));
+    return createLabel(parent, text);
+}
+
+static KSqueezedTextLabel *createSqueezedLabel(QWidget *parent, const QString &text)
+{
+    KSqueezedTextLabel *label = new KSqueezedTextLabel(text, parent);
+    label->setAlignment(Qt::AlignHCenter);
+    label->setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Fixed);
+    return label;
+}
+
 /** @internal */
 class RenameDialog::RenameDialogPrivate
 {
@@ -71,6 +105,8 @@ public:
         m_destPendingPreview = false;
         m_srcPreview = 0;
         m_destPreview = 0;
+        m_srcArea = Q_NULLPTR;
+        m_destArea = Q_NULLPTR;
     }
 
     void setRenameBoxText(const QString &fileName)
@@ -119,7 +155,7 @@ RenameDialog::RenameDialog(QWidget *parent, const QString &_caption,
                            const QDateTime &mtimeDest)
     : QDialog(parent), d(new RenameDialogPrivate)
 {
-    setObjectName("KIO::RenameDialog");
+    setObjectName(QStringLiteral("KIO::RenameDialog"));
 
     d->src = _src;
     d->dest = _dest;
@@ -202,8 +238,8 @@ RenameDialog::RenameDialog(QWidget *parent, const QString &_caption,
             d->destItem = KFileItem(destUds, d->dest);
         }
 
-        d->m_srcPreview = createLabel(parent, QString(), false);
-        d->m_destPreview = createLabel(parent, QString(), false);
+        d->m_srcPreview = createLabel(parent, QString());
+        d->m_destPreview = createLabel(parent, QString());
 
         d->m_srcPreview->setMinimumHeight(KIconLoader::SizeEnormous);
         d->m_destPreview->setMinimumHeight(KIconLoader::SizeEnormous);
@@ -227,40 +263,41 @@ RenameDialog::RenameDialog(QWidget *parent, const QString &_caption,
         QGridLayout *gridLayout = new QGridLayout();
         pLayout->addLayout(gridLayout);
 
+        int gridRow = 0;
         QLabel *titleLabel = new QLabel(i18n("This action will overwrite the destination."), this);
-
-        QLabel *srcTitle = createLabel(parent, i18n("Source"), true);
-        QLabel *destTitle = createLabel(parent, i18n("Destination"), true);
-
-        QLabel *srcInfo = createSqueezedLabel(parent, d->src.toDisplayString(QUrl::PreferLocalFile));
-        QLabel *destInfo = createSqueezedLabel(parent, d->dest.toDisplayString(QUrl::PreferLocalFile));
+        gridLayout->addWidget(titleLabel, gridRow, 0, 1, 2);    // takes the complete first line
 
         if (mtimeDest > mtimeSrc) {
             QLabel *warningLabel = new QLabel(i18n("Warning, the destination is more recent."), this);
 
-            gridLayout->addWidget(titleLabel, 0, 0, 1, 2);    // takes the complete first line
-            gridLayout->addWidget(warningLabel, 1, 0, 1, 2);
-            gridLayout->setRowMinimumHeight(2, 15);    // spacer
-
-            gridLayout->addWidget(srcTitle, 3, 0);
-            gridLayout->addWidget(srcInfo, 4, 0);
-            gridLayout->addWidget(d->m_srcArea, 5, 0);
-
-            gridLayout->addWidget(destTitle, 3, 1);
-            gridLayout->addWidget(destInfo, 4, 1);
-            gridLayout->addWidget(d->m_destArea, 5, 1);
-        } else {
-            gridLayout->addWidget(titleLabel, 0, 0, 1, 2);
-            gridLayout->setRowMinimumHeight(1, 15);
-
-            gridLayout->addWidget(srcTitle, 2, 0);
-            gridLayout->addWidget(srcInfo, 3, 0);
-            gridLayout->addWidget(d->m_srcArea, 4, 0);
-
-            gridLayout->addWidget(destTitle, 2, 1);
-            gridLayout->addWidget(destInfo, 3, 1);
-            gridLayout->addWidget(d->m_destArea, 4, 1);
+            gridLayout->addWidget(warningLabel, ++gridRow, 0, 1, 2);
         }
+        gridLayout->setRowMinimumHeight(++gridRow, 15);    // spacer
+
+        QLabel *srcTitle = createLabel(parent, i18n("Source"), true);
+        gridLayout->addWidget(srcTitle, ++gridRow, 0);
+        QLabel *destTitle = createLabel(parent, i18n("Destination"), true);
+        gridLayout->addWidget(destTitle, gridRow, 1);
+
+        QLabel *srcUrlLabel = createSqueezedLabel(parent, d->src.toDisplayString(QUrl::PreferLocalFile));
+        gridLayout->addWidget(srcUrlLabel, ++gridRow, 0);
+        QLabel *destUrlLabel = createSqueezedLabel(parent, d->dest.toDisplayString(QUrl::PreferLocalFile));
+        gridLayout->addWidget(destUrlLabel, gridRow, 1);
+
+        // The labels containing previews or icons
+        gridLayout->addWidget(d->m_srcArea, ++gridRow, 0);
+        gridLayout->addWidget(d->m_destArea, gridRow, 1);
+
+        QLabel *srcDateLabel = createDateLabel(parent, d->srcItem);
+        gridLayout->addWidget(srcDateLabel, ++gridRow, 0);
+        QLabel *destDateLabel = createDateLabel(parent, d->destItem);
+        gridLayout->addWidget(destDateLabel, gridRow, 1);
+
+        QLabel *srcSizeLabel = createSizeLabel(parent, d->srcItem);
+        gridLayout->addWidget(srcSizeLabel, ++gridRow, 0);
+        QLabel *destSizeLabel = createSizeLabel(parent, d->destItem);
+        gridLayout->addWidget(destSizeLabel, gridRow, 1);
+
     } else {
         // This is the case where we don't want to allow overwriting, the existing
         // file must be preserved (e.g. when renaming).
@@ -347,12 +384,18 @@ RenameDialog::RenameDialog(QWidget *parent, const QString &_caption,
     layout->addWidget(d->bCancel);
 
     resize(sizeHint());
+
+#if 1 // without kfilemetadata
+    // don't wait for kfilemetadata, but wait until the layouting is done
+    if (_options & RenameDialog_Overwrite) {
+        QMetaObject::invokeMethod(this, "resizePanels", Qt::QueuedConnection);
+    }
+#endif
 }
 
 RenameDialog::~RenameDialog()
 {
     delete d;
-    // no need to delete Pushbuttons,... qt will do this
 }
 
 void RenameDialog::enableRenameButton(const QString &newDest)
@@ -433,8 +476,6 @@ void RenameDialog::suggestNewNamePressed()
 
     QUrl destDirectory = d->dest.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash);
     d->setRenameBoxText(KIO::suggestName(destDirectory, d->m_pLineEdit->text()));
-
-    return;
 }
 
 void RenameDialog::skipPressed()
@@ -547,11 +588,16 @@ void RenameDialog::showDestPreview(const KFileItem &fileitem, const QPixmap &pix
 
 void RenameDialog::resizePanels()
 {
+    Q_ASSERT(d->m_srcArea != Q_NULLPTR);
+    Q_ASSERT(d->m_destArea != Q_NULLPTR);
+    Q_ASSERT(d->m_srcPreview != Q_NULLPTR);
+    Q_ASSERT(d->m_destPreview != Q_NULLPTR);
+
     // using QDesktopWidget geometry as Kephal isn't accessible here in kdelibs
-    QSize screenSize = QApplication::desktop()->availableGeometry(this).size();
+    const QSize screenSize = QApplication::desktop()->availableGeometry(this).size();
     QSize halfSize = d->m_srcArea->widget()->sizeHint().expandedTo(d->m_destArea->widget()->sizeHint());
-    QSize currentSize = d->m_srcArea->size().expandedTo(d->m_destArea->size());
-    int maxHeightPossible = screenSize.height() - (size().height() - currentSize.height());
+    const QSize currentSize = d->m_srcArea->size().expandedTo(d->m_destArea->size());
+    const int maxHeightPossible = screenSize.height() - (size().height() - currentSize.height());
     QSize maxHalfSize = QSize(screenSize.width() / qreal(2.1), maxHeightPossible * qreal(0.9));
 
     if (halfSize.height() > maxHalfSize.height() &&
@@ -586,13 +632,14 @@ QScrollArea *RenameDialog::createContainerLayout(QWidget *parent, const KFileIte
     KFileItemList itemList;
     itemList << item;
 
-#pragma message("TODO: use KFileMetaDataWidget in RenameDialog via a plugin")
 #if 0 // PENDING
-    // widget
+    // KFileMetaDataWidget was deprecated for a Nepomuk widget, which is itself deprecated...
+    // If we still want metadata shown, we need a plugin that fetches data from KFileMetaData::ExtractorCollection
     KFileMetaDataWidget *metaWidget =  new KFileMetaDataWidget(this);
 
     metaWidget->setReadOnly(true);
     metaWidget->setItems(itemList);
+    // ### This is going to call resizePanels twice! Need to split it up to do preview job only once on each side
     connect(metaWidget, SIGNAL(metaDataRequestFinished(KFileItemList)), this, SLOT(resizePanels()));
 #endif
 
@@ -620,30 +667,3 @@ QScrollArea *RenameDialog::createContainerLayout(QWidget *parent, const KFileIte
     return metaDataArea;
 }
 
-QLabel *RenameDialog::createLabel(QWidget *parent, const QString &text, bool containerTitle)
-{
-    QLabel *label = new QLabel(parent);
-
-    if (containerTitle) {
-        QFont font = label->font();
-        font.setBold(true);
-        label->setFont(font);
-    }
-
-    label->setAlignment(Qt::AlignHCenter);
-    label->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
-    label->setText(text);
-
-    return label;
-}
-
-KSqueezedTextLabel *RenameDialog::createSqueezedLabel(QWidget *parent, const QString &text)
-{
-    KSqueezedTextLabel *label = new KSqueezedTextLabel(text, parent);
-
-    label->setAlignment(Qt::AlignHCenter);
-    label->setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Fixed);
-
-    return label;
-}
-
